<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use Validator;
use App\Category;
use App\Media;

class CategoryController extends Controller {

    public function __construct() {
        if (!file_exists('uploads/category')) {
            mkdir('uploads/category', 0777, true);
        }
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request) {
        $type = $request->type;
        $category = Category::with('category')->where('type', $type)->get();
        return view('category.index', compact('category', 'type'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request) {
        $type = $request->type;
        $categoryParent = Category::where('type', $type)->get();
        $category = NULL;
        return view('category.form', compact('category', 'categoryParent', 'type'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {

        $validator = Validator::make($request->all(), [
                    'title' => 'required',
                    'image' => 'required',
                    'type' => 'required',
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $category = new Category($request->all());
        $file = $request->file('image');
        $path = $this->destinationFolder . "category/";
        $uniqueID = time();
        $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
        $category->image = $path . $uniqueID . "." . $file->getClientOriginalExtension();
        if ($request->hasFile('banner_img')) {
            $file = $request->file('banner_img');
            $path = $this->destinationFolder . "category/";
            $uniqueID = time();
            $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
            $category->banner_img = $path . $uniqueID . "." . $file->getClientOriginalExtension();
        }
        if (empty($request->parent_id)) {
            $category->parent_id = null;
        }
        $category->save();
        $request->session()->flash('success', 'Category Created Successfully');
        return redirect('category?type=' . $category->type);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id) {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id) {

        $category = Category::findOrFail($id);
        $categoryParent = Category::where('type', $category->type)->get();

        return view('category.form', compact('category', 'categoryParent'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id) {
        $validator = Validator::make($request->all(), [
                    'title' => 'required',
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator);
        }
        $oldCategory = Category::findOrFail($id);
        $category = $request->all();

        if ($request->hasFile('image')) {
            $file = $request->file('image');
            $path = $this->destinationFolder . "category/";
            $uniqueID = time();
            $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
            $category['image'] = $path . $uniqueID . "." . $file->getClientOriginalExtension();
            $this->delete_image_if_exists($oldCategory->image);
        }
        if ($request->hasFile('banner_img')) {
            $file = $request->file('banner_img');
            $path = $this->destinationFolder . "category/";
            $uniqueID = time();
            $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
            $category['banner_img'] = $path . $uniqueID . "." . $file->getClientOriginalExtension();
            $this->delete_image_if_exists($oldCategory->banner_img);
        }
        if (empty($request->parent_id)) {
            $category['parent_id'] = null;
        }
        $oldCategory->update($category);
        \Session::flash('success', 'Category Updated Successfully');
        return redirect('category?type=' . $oldCategory->type);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id) {
        $category = Category::findOrFail($id);
        $category->delete();
        $this->delete_image_if_exists($category->image);
        $this->delete_image_if_exists($category->banner_img);
        \Session::flash('success', 'Category Deleted Successfully');
        return redirect('media?type=' . $request->type);
    }

    public function img_delete(Request $request) {
        $id = $request->id;
        $CategoryImg = Category::findOrFail($id);
        $this->delete_image_if_exists($CategoryImg->banner_img);
        $category['banner_img'] = '';
        $del = $CategoryImg->update($category);
        if ($del)
            return Response('success');

        return Response('failed');
    }

    public function media($id) {
        $Category = Category::findOrFail($id);
        $type = $Category->type;
        $media = Media::where('category_id', $Category->id)->get();

        return view('media.index', compact('media', 'type'));
    }

}
