<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use Validator;
use App\Certification;

class CertificationsController extends Controller {

    public function __construct() {
        if (!file_exists('uploads/certifications')) {
            mkdir('uploads/certifications', 0777, true);
        }
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index() {
        $certifications = Certification::all();
        return view('certifications.index', compact('certifications'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request) {


        $certifications = NULL;

        return view('certifications.form', compact('certifications'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
                    'title' => 'required|unique:certifications,title',
                    'owner' => 'required',
                    'image' => 'required',
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $certifications = new Certification($request->all());
        $file = $request->file('image');
        $path = $this->destinationFolder . "certifications/";
        $uniqueID = time();
        $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
        $certifications->image = $path . $uniqueID . "." . $file->getClientOriginalExtension();
        $certifications->save();
        $request->session()->flash('success', 'Certification Created Successfully');
        return redirect('certifications');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id) {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id) {

        $certifications = Certification::findOrFail($id);

        return view('certifications.form', compact('certifications'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id) {
        $validator = Validator::make($request->all(), [
                    'title' => 'required|unique:certifications,title,' . $id,
                    'owner' => 'required',
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator);
        }
        $oldCertification = Certification::findOrFail($id);
        $certifications = $request->all();

        if ($request->hasFile('image')) {
            $file = $request->file('image');
            $path = $this->destinationFolder . "certifications/";
            $uniqueID = time();
            $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
            $certifications['image'] = $path . $uniqueID . "." . $file->getClientOriginalExtension();
            $this->delete_image_if_exists($oldCertification->image);
        }

        $oldCertification->update($certifications);
        \Session::flash('success', 'Certification Updated Successfully');
        return redirect('certifications');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id) {
        $certifications = Certification::findOrFail($id);
        $certifications->delete();
        $this->delete_image_if_exists($certifications->image);
        \Session::flash('success', 'Certification Deleted Successfully');
        return redirect('certifications');
    }

}
