<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use Validator;
use App\Category;
use App\Media;

class MediaController extends Controller {

    public function __construct() {
        if (!file_exists('uploads/media')) {
            mkdir('uploads/media', 0777, true);
        }
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request) {
        $type = $request->type;    
        $media = Media::Join('media_category', 'media_category.id', '=', 'media.category_id')
                        ->where('media_category.type', $type)
                        ->select('media.*')->get();

        return view('media.index', compact('media', 'type'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request) {
        $type = $request->type;
        $category = Category::where('type', $type)->get();
        if ($request->category_id)
            $category_id = $request->category_id;
        else
            $category_id = NULL;
        $media = NULL;

        return view('media.form', compact('media', 'category', 'category_id', 'type'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {

        $validator = Validator::make($request->all(), [
                    'title' => 'required',
                    'image' => 'required',
                    'category_id' => 'required',
                    'source' => 'required',
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $media = new Media($request->all());
        $file = $request->file('image');
        $path = $this->destinationFolder . "media/";
        $uniqueID = time();
        $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
        $media->image = $path . $uniqueID . "." . $file->getClientOriginalExtension();
        $media->save();
        $request->session()->flash('success', 'Media Created Successfully');
        return redirect('media?type=' . $request->type);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id) {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id) {
        $category_id=$type = null;
        $media = Media::findOrFail($id);
        $category = Category::where('type', $media->category->type)->get();

        return view('media.form', compact('media', 'category', 'category_id','type','category_id'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id) {
        $validator = Validator::make($request->all(), [
                    'title' => 'required',
                    'category_id' => 'required',
                    'source' => 'required',
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator);
        }
        $oldMedia = Media::findOrFail($id);
        $media = $request->all();

        if ($request->hasFile('image')) {
            $file = $request->file('image');
            $path = $this->destinationFolder . "media/";
            $uniqueID = time();
            $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
            $media['image'] = $path . $uniqueID . "." . $file->getClientOriginalExtension();
            $this->delete_image_if_exists($oldMedia->image);
        }
        $oldMedia->update($media);
        \Session::flash('success', 'Media Updated Successfully');
        return redirect('media?type=' . $oldMedia->category->type);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id) {
        $media = Media::findOrFail($id);
        $media->delete();
        $this->delete_image_if_exists($media->image);
        $this->delete_image_if_exists($media->banner_img);
        \Session::flash('success', 'Media Deleted Successfully');
         return back();
    }

}
