<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use Validator;
use App\Reward;

class RewardsController extends Controller {
   
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index() {
        $rewards = Reward::all();
        return view('rewards.index', compact('rewards'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request) {


        $rewards = NULL;

        return view('rewards.form', compact('rewards'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
                    'title' => 'required|unique:rewards,title',
                    'description' => 'required',
                    
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $rewards = new Reward($request->all());       
        $rewards->save();
        $request->session()->flash('success', 'Reward Created Successfully');
        return redirect('rewards');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id) {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id) {

        $rewards = Reward::findOrFail($id);

        return view('rewards.form', compact('rewards'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id) {
        $validator = Validator::make($request->all(), [
                    'title' => 'required|unique:rewards,title,' . $id,
                    'description' => 'required',
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator);
        }
        $oldReward = Reward::findOrFail($id);
        $rewards = $request->all();

        $oldReward->update($rewards);
        \Session::flash('success', 'Reward Updated Successfully');
        return redirect('rewards');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id) {
        $rewards = Reward::findOrFail($id);
        $rewards->delete();       
        \Session::flash('success', 'Reward Deleted Successfully');
        return redirect('rewards');
    }

}
