<?php

namespace App\Http\Controllers;

use App\Layer;
use App\Slider;
use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use Validator;

class SliderController extends Controller {

    public function __construct() {
        if (!file_exists('uploads/slider')) {
            mkdir('uploads/slider', 0777, true);
        }
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index() {
        $sliders = Slider::orderBy('order', 'ASC')->get();
        return view('slider.index', compact('sliders'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create() {
        
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
                    'image' => 'required',
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $slider = new Slider($request->all());
        $file = $request->file('image');
        $path = $this->destinationFolder . "slider/";
        $uniqueID = time();
        $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
        $slider->main_image = $path . $uniqueID . "." . $file->getClientOriginalExtension();
        if ($slider->save())
            return Response(array('data' => 'success'));
        else
            return Response(array('data' => 'failed'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id) {
        
        $slider = Slider::findOrFail($id);
        $layers = Layer::where('slide_id',$id)->orderBy('order', 'ASC')->get();
        return view('layer.index', compact('layers','slider'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id) {
        
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id) {
        $sliderImg = Slider::findOrFail($id);
        $newSlider = $request->all();
        if ($request->hasFile('image')) {
            $file = $request->file('image');
            $path = $this->destinationFolder . "slider/";
            $uniqueID = time();
            $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
            $newSlider['main_image'] = $path . $uniqueID . "." . $file->getClientOriginalExtension();
            $this->delete_image_if_exists($sliderImg->main_image);
        }
        $ed = $sliderImg->update($newSlider);
        if ($ed)
            return Response(array('data' => 'success'));
        else
            return Response(array('data' => 'failed'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request) {
        $id = $request->id;
        $sliderImg = Slider::findOrFail($id);
        $this->delete_image_if_exists($sliderImg->main_image);
        $del = $sliderImg->delete();
        if ($del)
            return Response('success');

        return Response('failed');
    }

    public function update_sequence(Request $request) {
        $items = $request->item;
        // return $items;
        $i = 1;
        foreach ($items as $item) {
            $img = Slider::find($item);
            $img->order = $i;
            $img->save();
            $i++;
        }
    }

}
